---
title: llarp/apple/route_manager.hpp

---

# llarp/apple/route_manager.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::apple](Namespaces/namespacellarp_1_1apple.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| class | **[llarp::apple::RouteManager](Classes/classllarp_1_1apple_1_1RouteManager.md)**  |




## Source code

```cpp
#pragma once

#include <llarp/router/abstractrouter.hpp>
#include <llarp/ev/vpn.hpp>
#include "context_wrapper.h"

namespace llarp::apple
{
  class RouteManager final : public llarp::vpn::IRouteManager
  {
   public:
    RouteManager(llarp::Context& ctx, llarp_route_callbacks rcs, void* callback_context)
        : context{ctx}, route_callbacks{std::move(rcs)}, callback_context{callback_context}
    {}

    void
    AddRoute(IPVariant_t ip, IPVariant_t gateway) override
    {}

    void
    DelRoute(IPVariant_t ip, IPVariant_t gateway) override
    {}

    void
    AddDefaultRouteViaInterface(std::string ifname) override;

    void
    DelDefaultRouteViaInterface(std::string ifname) override;

    void
    AddRouteViaInterface(vpn::NetworkInterface& vpn, IPRange range) override;

    void
    DelRouteViaInterface(vpn::NetworkInterface& vpn, IPRange range) override;

    virtual std::vector<IPVariant_t>
    GetGatewaysNotOnInterface(std::string ifname) override
    {
      // We can't get this on mac from our sandbox, but we don't actually need it because we
      // ignore the gateway for AddRoute/DelRoute anyway, so just return a zero IP.
      std::vector<IPVariant_t> ret;
      ret.push_back(huint32_t{0});
      return ret;
    }

   private:
    llarp::Context& context;
    bool trampoline_active = false;
    std::vector<llarp::SockAddr> saved_upstream_dns;
    void
    check_trampoline(bool enable);

    void* callback_context = nullptr;
    llarp_route_callbacks route_callbacks;
  };

}  // namespace llarp::apple
```


-------------------------------

Updated on 2022-09-12 at 22:16:01 +0000
